@@ -7,14 +7,14 @@ import reviewboard
 
 class RBHTTPAuthBackend(reviewboard.accounts.backends.AuthBackend):
     name = 'RBHTTPAuthBackend'
-    the_url = "http://localhost" + settings.SITE_ROOT
+    the_url = "http://localhost"
     def authenticate(self, username, password):
 
         username = username.strip()
 
         try:
             passman = urllib2.HTTPPasswordMgrWithDefaultRealm()
-            passman.add_password(None, self.the_url, username, password) 
+            passman.add_password(None, self.the_url, username, password)
             authhandler = urllib2.HTTPBasicAuthHandler(passman)
             opener = urllib2.build_opener(authhandler)
             urllib2.install_opener(opener)
